<?php
/*
The settings page
*/

function crimson_cp_scripts_styles() {
	if(!is_admin())
		return;
	
	$file_dir = get_template_directory_uri();
	wp_enqueue_style("options_panel_stylesheet", $file_dir."/css/options-panel.css", false, "1.0", "all");
	wp_enqueue_script("options_panel_script", $file_dir."/js/options-panel.js", false, "1.0");
}
add_action('admin_init', 'crimson_cp_scripts_styles');

function crimson_theme_menu() {
    add_theme_page(  
        'Crimson Settings',            // The title to be displayed in the browser window for this page.  
        'Crimson Settings',            			// The text to be displayed for this menu item
        'administrator',            				// Which type of users can see this menu item  
        'crimson_settings',    							// The unique ID - that is, the slug - for this menu item  
        'crimson_render_settings_page'     				// The name of the function to call when rendering this menu's page  
    );  
  
}
add_action( 'admin_menu', 'crimson_theme_menu' );

function crimson_render_settings_page() {
?>
<div class="wrap">
<div id="icon-options-general" class="icon32"></div>
<h2>Crimson Settings</h2>
<div class="cp-sidebar"><span>Need help?</span><br/><br/><a class="cp-button" target="_blank" href="http://wpgurus.net/hire-me/">Hire Me</a></div>
<div class="sections-wrap">
	<form method="post" action="options.php">
		<?php settings_fields( 'crimson_settings' ); ?>
		<?php do_settings_sections( 'crimson_settings' ); ?>
		</div></div> <!--For the last section-->
	</form>
</div>

</div>
<?php }

function crimson_initialize_theme_options() { 

    // First, we register a section. This is necessary since all future options must belong to a   
    add_settings_section(  
        'general_settings_section',
        '',
        'crimson_general_settings_section_callback',
        'crimson_settings' 
    );
	
	add_settings_section(  
        'home_settings_section',
        '',
        'crimson_home_settings_section_callback', 
        'crimson_settings' 
    );
	
	add_settings_section(  
        'social_settings_section',
        '',
        'crimson_social_settings_section_callback', 
        'crimson_settings' 
    );
	
	add_settings_section(  
        'footer_settings_section', 
        '',
        'crimson_footer_settings_section_callback',
        'crimson_settings'
    );
  
    add_settings_field(
        'custom_favicon', 'Custom Favicon', 'crimson_render_settings_field', 'crimson_settings', 'general_settings_section',
		array( 
			'desc' => 'A favicon is a 16x16 pixel icon that represents your site; paste the URL to a .ico image that you want to use as the image',
			'id' => 'favicon',
			'type' => 'text',
			'group' => 'crimson_general_settings'
		)
    );
	
	add_settings_field(
        'color_scheme', 'Color Scheme', 'crimson_render_settings_field', 'crimson_settings', 'general_settings_section',
		array(
			'desc' => 'Select the colour scheme for the theme',
			'id' => 'color_scheme',
			'type' => 'select',
			'options' => array("red" => "Red", "blue" => "Blue", "green" => "Green"),
			'group' => 'crimson_general_settings'
		)
    );
	
	add_settings_field(
        'logo_url', 'Logo URL', 'crimson_render_settings_field', 'crimson_settings', 'general_settings_section',
		array(
			'desc' => 'Enter the link to your logo image',
			'id' => 'logo',
			'type' => 'text',
			'group' => 'crimson_general_settings'
		)  
    );
	
	/*add_settings_field(
        'custom_css', 'Custom CSS', 'crimson_render_settings_field', 'crimson_settings', 'general_settings_section', 
		array(
			'desc' => 'Want to add any custom CSS code? Put in here, and the rest is taken care of. This overrides any other stylesheets. eg: a.button{color:green}',
			'id' => 'custom_css',
			'type' => 'textarea',
			'group' => 'crimson_general_settings'
		)
    );*/
	
	add_settings_field(
        'disable_banner', 'Disable banner?', 'crimson_render_settings_field', 'crimson_settings', 'home_settings_section',
		array(  
			'desc' => 'Check if you want to disable the banner present under the header',
			'id' => 'disable_banner',
			'type' => 'checkbox',
			'group' => 'crimson_home_settings'
		)
    );
	
	add_settings_field(
        'banner_heading', 'Banner Heading', 'crimson_render_settings_field', 'crimson_settings', 'home_settings_section',
		array(  
			'desc' => 'The main heading for the banner on homepage',
			'id' => 'banner_heading',
			'type' => 'text',
			'group' => 'crimson_home_settings'
		)
    );
	
	add_settings_field(
        'banner_sub_heading', 'Banner Sub-Heading', 'crimson_render_settings_field', 'crimson_settings', 'home_settings_section',
		array(  
			'desc' => 'The sub-heading for the banner on homepage',
			'id' => 'banner_sub_heading',
			'type' => 'text',
			'group' => 'crimson_home_settings'
		)
    );
	
	add_settings_field(
        'banner_description', 'Banner Description', 'crimson_render_settings_field', 'crimson_settings', 'home_settings_section',
		array(  
			'desc' => 'The description that goes in the banner on homepage',
			'id' => 'banner_description',
			'type' => 'textarea',
			'group' => 'crimson_home_settings'
		)
    );
	
	add_settings_field(
        'intro_video_code', 'Embed Code of Introductory Video', 'crimson_render_settings_field', 'crimson_settings', 'home_settings_section',
		array(  
			'desc' => 'The embedding code of the video or image you want placed in the banner section on homepage',
			'id' => 'intro_video_code',
			'type' => 'textarea',
			'group' => 'crimson_home_settings'
		)
    );
	
	add_settings_field(
        'banner_button_color', 'Button Color', 'crimson_render_settings_field', 'crimson_settings', 'home_settings_section',
		array(
			'desc' => 'Color of the button',
			'id' => 'banner_button_color',
			'type' => 'select',
			'options' => array('green' => 'Green', 'blue' => 'Blue', 'red' => 'Red', 'orange' => 'Orange'),
			'group' => 'crimson_home_settings'
		)
    );
	
	add_settings_field(
        'banner_button_link', 'Button Link', 'crimson_render_settings_field', 'crimson_settings', 'home_settings_section',
		array(
			'desc' => 'Page that the button should link to. Leave empty to hide the button',
			'id' => 'banner_button_link',
			'type' => 'text',
			'group' => 'crimson_home_settings'
		)
    );
	
	add_settings_field(
        'banner_button_text', 'Button Text', 'crimson_render_settings_field', 'crimson_settings', 'home_settings_section',
		array(
			'desc' => 'Text of the button.',
			'id' => 'banner_button_text',
			'type' => 'text',
			'group' => 'crimson_home_settings'
		)
    );
	
	add_settings_field(
        'show_excerpts', 'Show Excerpts', 'crimson_render_settings_field', 'crimson_settings', 'home_settings_section',
		array(  
			'desc' => 'Do you want to show excerpts on homepage? Keep this box unchecked if you want to show the whole post.',
			'id' => 'show_excerpts',
			'type' => 'checkbox',
			'group' => 'crimson_home_settings'
		)
    );
	
	add_settings_field(
        'twitter_url', 'Twitter URL', 'crimson_render_settings_field', 'crimson_settings', 'social_settings_section',
		array( 
			'name' => 'Twitter URL',
			'desc' => 'Enter the URL of your Twitter page.',
			'id' => 'twitter_url',
			'type' => 'text',
			'group' => 'crimson_social_settings'
		)
    );
	
	add_settings_field(
        'fb_url', 'Facebook URL', 'crimson_render_settings_field', 'crimson_settings', 'social_settings_section',
		array(
			'desc' => 'Enter the URL of your Facebook fan page.',
			'id' => 'fb_url',
			'type' => 'text',
			'group' => 'crimson_social_settings'
		)
    );
	
	add_settings_field(
        'google_plus_url', 'Google Plus URL', 'crimson_render_settings_field', 'crimson_settings', 'social_settings_section',
		array( 
			'desc' => 'Enter the URL of your Google page.',
			'id' => 'google_plus_url',
			'type' => 'text',
			'group' => 'crimson_social_settings'
		)
    );
	
	add_settings_field(
        'feedburner', 'Feedburner URL', 'crimson_render_settings_field', 'crimson_settings', 'social_settings_section',
		array( 
			'desc' => 'Feedburner is a Google service that takes care of your RSS feed. Paste your Feedburner URL here to let readers see it in your website',
			'id' => 'feedburner',
			'type' => 'text',
			'group' => 'crimson_social_settings'
		)
    );
	
	add_settings_field(
        'footer_text', 'Footer Copyright Text', 'crimson_render_settings_field', 'crimson_settings', 'footer_settings_section',
		array(
			'desc' => 'Enter text used in the left side of the footer.',
			'id' => 'footer_text',
			'type' => 'text',
			'group' => 'crimson_footer_settings'
		)
    );
	
	add_settings_field(
        'hide_credits', 'Hide credit link?', 'crimson_render_settings_field', 'crimson_settings', 'footer_settings_section',
		array(
			'desc' => 'Do you want to hide the credit link in footer?',
			'id' => 'hide_credits',
			'type' => 'select',
			'options' => array('sitewide' => 'Show on all pages', 'nofollow' => 'Show but add no-follow attribute', 'homepage' => 'Show only on homepage', 'hide' => 'Hide completely'),
			'group' => 'crimson_footer_settings'
		)
    );
	
    // Finally, we register the fields with WordPress 
	register_setting('crimson_settings', 'crimson_general_settings');
	register_setting('crimson_settings', 'crimson_home_settings');
	register_setting('crimson_settings', 'crimson_social_settings');
	register_setting('crimson_settings', 'crimson_footer_settings');
	
} // end sandbox_initialize_theme_options 
add_action('admin_init', 'crimson_initialize_theme_options');

function crimson_general_settings_section_callback(){
	echo '<div class="section"><div class="section-title"><h3>General</h3>';
	submit_button('Save Changes', 'secondary','submit', false);
	echo '<div class="clearfix"></div></div><div class="section-options">';
}

function crimson_home_settings_section_callback(){
	echo '</div></div><div class="section"><div class="section-title"><h3>Homepage</h3>';
	submit_button('Save Changes', 'secondary','submit', false);
	echo '<div class="clearfix"></div></div><div class="section-options">';
}

function crimson_social_settings_section_callback(){
	echo '</div></div><div class="section"><div class="section-title"><h3>Social Links</h3>';
	submit_button('Save Changes', 'secondary','submit', false);
	echo '<div class="clearfix"></div></div><div class="section-options">';
}

function crimson_footer_settings_section_callback(){
	echo '</div></div><div class="section"><div class="section-title"><h3>Footer</h3>';
	submit_button('Save Changes', 'secondary','submit', false);
	echo '<div class="clearfix"></div></div><div class="section-options">';
}

function crimson_render_settings_field($args){
	$option_value = get_option($args['group']);
	
	if($args['type'] == 'text'){
?>
		<input type="text" id="<?php echo $args['id'] ?>" name="<?php echo $args['group'].'['.$args['id'].']'; ?>" value="<?php echo esc_attr($option_value[$args['id']]); ?>">
		<small><?php echo $args['desc'] ?></small>
<?php
	}
	else if ($args['type'] == 'select')
	{ 
?>
		<select name="<?php echo $args['group'].'['.$args['id'].']'; ?>" id="<?php echo $args['id']; ?>">
			<?php foreach ($args['options'] as $key=>$option) { ?>
				<option <?php selected($option_value[$args['id']], $key); echo 'value="'.$key.'"'; ?>><?php echo $option; ?></option><?php } ?>
		</select>
		<small><?php echo $args['desc']; ?></small>
<?php	
	}
	else if($args['type'] == 'checkbox')
	{
?>		
		<input type="hidden" name="<?php echo $args['group'].'['.$args['id'].']'; ?>" value="0" />
		<input type="checkbox" name="<?php echo $args['group'].'['.$args['id'].']'; ?>" id="<?php echo $args['id']; ?>" value="1" <?php checked($option_value[$args['id']]); ?> />
		<small><?php echo $args['desc']; ?></small><div class="clearfix"></div>
<?php
	}
	else if($args['type'] == 'textarea')
	{
?>
		<textarea name="<?php echo $args['group'].'['.$args['id'].']'; ?>" type="<?php echo $args['type']; ?>" cols="" rows=""><?php if ( $option_value[$args['id']] != "") { echo stripslashes(esc_textarea($option_value[$args['id']]) ); } ?></textarea>
		<small><?php echo $args['desc']; ?></small><div class="clearfix"></div>
<?php
	}
}

?>